@@ -54,6 +54,9 @@ static gboolean foobar_leave_notify	(GtkWidget *widget,
 					 GdkEventCrossing *event);
 static gboolean foobar_enter_notify	(GtkWidget *widget,
 					 GdkEventCrossing *event);
+static gboolean foobar_key_press	(GtkWidget *widget,
+					 GdkEventKey *event);
+static void foobar_widget_move_focus_out   (FoobarWidget *foo);
 static void foobar_widget_move_focus_out   (FoobarWidget *foo);
 static void append_task_menu (FoobarWidget *foo, GtkMenuShell *menu_bar);
 static void setup_task_menu (FoobarWidget *foo);
@@ -108,6 +111,7 @@ foobar_widget_class_init (FoobarWidgetClass *klass)
 	widget_class->size_allocate = foobar_widget_size_allocate;
 	widget_class->enter_notify_event = foobar_enter_notify;
 	widget_class->leave_notify_event = foobar_leave_notify;
+	widget_class->key_press_event = foobar_key_press;
 
 	klass->move_focus_out = foobar_widget_move_focus_out;
 
@@ -135,31 +139,26 @@ foobar_widget_class_init (FoobarWidgetClass *klass)
 	gtk_binding_entry_add_signal (binding_set,
                                       GDK_KP_Tab, GDK_CONTROL_MASK,
                                       "move_focus_out", 0);
-	gtk_binding_entry_add_signal (binding_set,
-                                      GDK_ISO_Left_Tab, GDK_CONTROL_MASK,
-                                      "move_focus_out", 0);
 
 
 }
 
-static GtkWidget *
-pixmap_menu_item_new (const char *text, const char *try_file, gboolean force_image)
+static gboolean
+foobar_key_press (GtkWidget *widget, GdkEventKey *event)
 {
-	GtkWidget *item;
-	GtkWidget *label;
+ 	FoobarWidget *foobar;
+	PanelWidget *panel;
 
-	item = gtk_image_menu_item_new ();
+	g_return_val_if_fail (FOOBAR_IS_WIDGET (widget), FALSE);
 
-	panel_load_menu_image_deferred (item, try_file, NULL /* fallback */,
-					force_image);
+	foobar = FOOBAR_WIDGET (widget);
 
-	if (text) {
-		label = gtk_label_new (text);
-		gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-		gtk_container_add (GTK_CONTAINER (item), label);
-	}
+	g_return_val_if_fail (PANEL_IS_WIDGET (foobar->panel), FALSE);
 
-	return item;
+	panel = PANEL_WIDGET (foobar->panel);
+
+	panel_widget_save_key_event (panel, event);
+	return GTK_WIDGET_CLASS (foobar_widget_parent_class)->key_press_event (widget, event);
 }
 
 static gboolean
@@ -181,12 +180,19 @@ foobar_enter_notify (GtkWidget *widget,
 		GTK_WIDGET_CLASS (foobar_widget_parent_class)->enter_notify_event (widget,
 								     event);
 
-	if (global_config.autoraise)
-		gdk_window_raise (widget->window);
-
 	return FALSE;
 }
 
+static void
+foobar_screenshot (GtkWidget *widget, gpointer data) 
+{
+	char *argv[2] = {"gnome-panel-screenshot", NULL};
+
+	if (gnome_execute_async (g_get_home_dir (), 1, argv) < 0)
+		panel_error_dialog ("cannot_exec_gnome-panel-screenshot",
+				    _("Cannot execute gnome-panel-screenshot"));
+}
+
 static void
 foobar_search (GtkWidget *widget,
 	       gpointer   data)
@@ -230,6 +236,18 @@ append_actions_menu (GtkWidget *menu_bar)
 				  G_CALLBACK (foobar_search), 0);
 	}
 
+	if (panel_is_program_in_path ("gnome-panel-screenshot")) {
+		item = pixmap_menu_item_new (_("Take a Screen Shot..."), "gnome-mdi.png", FALSE);
+		gtk_tooltips_set_tip (panel_tooltips, item,
+			      	      _("Take a screen shot of your desktop"),
+			              NULL);
+		gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+        	g_signal_connect (G_OBJECT (item), "activate",
+			  	  G_CALLBACK (foobar_screenshot), 0);	 
+	}
+
+	item = gtk_separator_menu_item_new ();
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 
 	if (panel_is_program_in_path  ("xscreensaver")) {
 		item = pixmap_menu_item_new (_("Lock Display"), 
@@ -328,6 +346,13 @@ set_the_task_submenu (FoobarWidget *foo, GtkWidget *item)
 static void
 focus_window (GtkWidget *w, WnckWindow *window)
 {
+	WnckWorkspace* space;
+
+	/* Make sure that the current workspace is the same as the app'
+	 * Same behaviour as GNOME 1.4 */
+	space = wnck_window_get_workspace (window);
+	wnck_workspace_activate (space);
+
 	if (wnck_window_is_minimized (window)) 
 		wnck_window_unminimize (window);
 
@@ -344,7 +369,7 @@ get_default_image (void)
 	if ( ! looked) {
 		pixbuf = panel_make_menu_icon ("gnome-tasklist.png",
 					       /* evil fallback huh? */
-					       "apple-red.png",
+					       "gnome-gmenu.png",
 					       20 /* size */,
 					       NULL /* long_operation */);
 
@@ -750,7 +775,7 @@ foobar_widget_instance_init (FoobarWidget *foo)
 
 	g_object_set_data (G_OBJECT (menu_bar), "menu_panel", foo->panel);
 
-	add_atk_name_desc (foo->panel, _("Base Panel"), _("Gnome Base Panel"));
+	add_atk_name_desc (foo->panel, _("Menu Panel"), _("GNOME Menu Panel"));
 
 	path = panel_pixmap_discovery ("panel-corner-right.png", FALSE /* fallback */);
 	if (path != NULL) {
@@ -846,6 +871,7 @@ foobar_widget_new (const char *panel_id, int screen)
 		panel_widget_set_id (PANEL_WIDGET (foo->panel), panel_id);
 
 	foo->screen = screen;
+
 	gtk_window_move (GTK_WINDOW (foo),
 			 multiscreen_x (foo->screen),
 			 multiscreen_y (foo->screen));
